
/*
 *  Called when there is unsaved data on the page to warn users leaving
 *  (or reloading) page that they would lose their changes.
 *  The onbeforeunload event works in FF, IE and Safari, but not in Opera (yet).
 *  The form of the dialog is unmodifiable:
 *  
 *  Are you sure you want to navigate away from this page?
 *  Your message here
 *  Press OK to continue, or Cancel to stay on the current page.
 */
(function ($, Drupal) {

  Drupal.markPageUnsaved = function(msg) {
    // Add the class and onbeforeunload only once.
    if (!$('body').is('.has-unsaved-changes')) {
      $('body').addClass('has-unsaved-changes');
      if (!msg) {
        // The default message.
        msg = "If you continue your unsaved changes will be lost.";
      }
      window.onbeforeunload = function() {return msg;};
      $(':submit, input:image').click(function() {
        // Turn off the warning before submit triggers it.
        window.onbeforeunload = null;
      });
    }
  };

  $(function () {
    msg = Drupal.settings.saveguard.msg;
    // Handle checkboxes, radio buttons and selects.
    $('input, select').change(function() {Drupal.markPageUnsaved(msg)});
    // Handle textfields and textareas.
    $('input, textarea').keypress(function() {Drupal.markPageUnsaved(msg)});
    // Mark as unsaved immediately if there are form errors.
    if (jQuery('.form-item .error').length > 0) Drupal.markPageUnsaved(msg);

    // Use the built-in ckeditor change event.  Requires CKEditor >= 4.2
    // http://ckeditor.com/forums/CKEditor/onChange-event-included-in-CKEditor-4.2
    if (typeof(CKEDITOR) != 'undefined' && typeof(CKEDITOR.instances) != 'undefined') {
      for (var i in CKEDITOR.instances) {
        CKEDITOR.instances[i].on('change', function() {Drupal.markPageUnsaved(msg)});
      }
    }
  });

})(jQuery, Drupal);
